@@ -3,5 +3,5 @@ from . import connector
 from . import devices
 from . import encoder
 from . import executor
-from . import logger
+from . import logging
 from . import worker
