@@ -32,12 +32,9 @@ class WorkerTestCase(
             ),
             logging=sergeant.config.Logging(
                 handlers=[
-                    sergeant.config.LoggingHandler(
-                        type='logstash',
-                        params={
-                            'host': 'localhost',
-                            'port': 9999,
-                        },
+                    sergeant.logging.logstash.LogstashHandler(
+                        host='localhost',
+                        port=9999,
                     ),
                 ],
             ),
@@ -47,12 +44,12 @@ class WorkerTestCase(
             obj=worker.logger,
         )
         self.assertEqual(
-            first=len(worker.logger.logger.handlers),
+            first=len(worker.logger.handlers),
             second=1,
         )
         self.assertIsInstance(
-            obj=worker.logger.logger.handlers[0],
-            cls=sergeant.logger.handlers.logstash.LogstashHandler,
+            obj=worker.logger.handlers[0],
+            cls=sergeant.logging.logstash.LogstashHandler,
         )
 
     def test_init_task_queue(
@@ -80,9 +77,8 @@ class WorkerTestCase(
             obj=worker.task_queue.connector,
             cls=sergeant.connector.redis.Connector,
         )
-        self.assertIsInstance(
+        self.assertIsNone(
             obj=worker.task_queue.encoder.compressor,
-            cls=sergeant.encoder.compressor.dummy.Compressor,
         )
         self.assertIsInstance(
             obj=worker.task_queue.encoder.serializer,
@@ -120,9 +116,8 @@ class WorkerTestCase(
             obj=worker.task_queue.connector,
             cls=sergeant.connector.redis_cluster.Connector,
         )
-        self.assertIsInstance(
+        self.assertIsNone(
             obj=worker.task_queue.encoder.compressor,
-            cls=sergeant.encoder.compressor.dummy.Compressor,
         )
         self.assertIsInstance(
             obj=worker.task_queue.encoder.serializer,
@@ -147,16 +142,16 @@ class WorkerTestCase(
             obj=worker.task_queue.connector,
             cls=sergeant.connector.mongo.Connector,
         )
-        self.assertIsInstance(
+        self.assertIsNone(
             obj=worker.task_queue.encoder.compressor,
-            cls=sergeant.encoder.compressor.dummy.Compressor,
         )
         self.assertIsInstance(
             obj=worker.task_queue.encoder.serializer,
             cls=sergeant.encoder.serializer.pickle.Serializer,
         )
 
-        compressor_names = sergeant.encoder.compressor.__compressors__.keys()
+        compressor_names = list(sergeant.encoder.compressor.__compressors__.keys())
+        compressor_names.append(None)
         serializer_names = sergeant.encoder.serializer.__serializers__.keys()
         for compressor_name in compressor_names:
             for serializer_name in serializer_names:
@@ -185,10 +180,15 @@ class WorkerTestCase(
                     obj=worker.task_queue.connector,
                     cls=sergeant.connector.redis.Connector,
                 )
-                self.assertEqual(
-                    first=worker.task_queue.encoder.compressor.name,
-                    second=compressor_name,
-                )
+                if compressor_name:
+                    self.assertEqual(
+                        first=worker.task_queue.encoder.compressor.name,
+                        second=compressor_name,
+                    )
+                else:
+                    self.assertIsNone(
+                        obj=worker.task_queue.encoder.compressor,
+                    )
                 self.assertEqual(
                     first=worker.task_queue.encoder.serializer.name,
                     second=serializer_name,
